package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`/@`!`````"9``#0````\LP```````#0`(``,
M`"@`'``;``8````T````-`!``#0`0`"``0``@`$```0````$`````P```+0!
M``"T`4``M`%``!H````:````!`````$````!````````````0````$``H!(`
M`*`2```$`````!````$`````(````"!````@0`#M,P``[3,```4`````$```
M`0````!@````8$```&!``"Q&```L1@``!``````0```!````B*X``(B^0`"(
MOD``@`,``,P3```&`````!````(```"0K@``D+Y``)"^0``8`0``&`$```8`
M```$````!````-`!``#0`4``T`%``'@```!X````!`````0```!3Y71D]`$`
M`/0!0`#T`4``-````#0````$````!````%#E=&1`GP``0)]``$"?0`#D````
MY`````0````$````4>5T9```````````````````````````!@```!````!2
MY71DB*X``(B^0`"(OD``>`$``'@!```$`````0```"]L:6)X,S(O;&0M;&EN
M=7@M>#,R+G-O+C(````$````%`````,```!'3E4`N<1)IR.;V%G;$Q^F,P.!
M4\$#(KP$````)`````4```!'3E4``H``P`0````!`````0`!P`0````)````
M`@`!P`0````!````!````!`````!````1TY5```````#````!``````````1
M````2@````@````(`````!`0!"5`!(`H````H(8`@(`!```+*`0(.*`218H`
M``@`````2@```$T```!0````40```%<```!8````60```%L```!<````````
M`%X```!?````8````&$``````````````&[%WQ_.WD<M:W^:?"[%F[8@_^0.
MU634?-EQ6!SB1\8!K$OCP+KCDGS"Y3\L^J%L8+,!BV]K"4/69Z_,9D)%U>R)
M!W#3#13BGMK-XYXS8MOM#3J7"W^IG)OAIP(*H^#[20``````````````````
M``#L`@`````````````2````\P(`````````````$@```&X"````````````
M`!(```"J`P`````````````2`````0``````````````(````&@"````````
M`````!(````.`P`````````````1````&`$`````````````$@```,P"````
M`````````!(```"D```````````````2````B@$`````````````$@```,4"
M`````````````!(```"#`@`````````````2````=```````````````$@``
M`!,!`````````````!(```"$`@`````````````2````\0``````````````
M$0```/T!`````````````!(````^`@`````````````2````#`,`````````
M````$0```&X!`````````````!(```#=`0`````````````2````TP``````
M````````$0```#P!`````````````!(```!A`@`````````````2````L@``
M````````````$@```+@!`````````````!(```"E`0`````````````2````
MY`$`````````````$@```$H!`````````````!(````I`@`````````````2
M````,`(`````````````$@```!T``````````````"````!:`@``````````
M```2````?`(`````````````$@```.0"`````````````!(```!3`@``````
M```````2````5```````````````$@```-8"`````````````!(````"`@``
M```````````2````@P``````````````$@```(\``````````````!(```!C
M`0`````````````2````*0$`````````````$@```*@"`````````````!(`
M``!&```````````````2````H0(`````````````$0```*\"````````````
M`!(```"9`@`````````````2````'0$`````````````$@```)H!````````
M`````!(```#@```````````````2````%@,`````````````$@```/P`````
M`````````!(```"X`@`````````````2````?`$`````````````$@```&,`
M`````````````!(```"Q`0`````````````2````BP(`````````````$@``
M`$4"`````````````!(````V`@`````````````2````^@(`````````````
M$@````<"`````````````!(```#$```````````````2````6@$`````````
M````$@```"P``````````````"````#U`0`````````````2````PP$`````
M````````$@```-<!`````````````!(````/`@`````````````2````&`(`
M````````````$@```$P"`````````````!(````-`P`````````````A````
MLP,``/!20`!=````$@`.`-\#``#01$``B@H``!(`#@`'`P``\"-```P"```2
M``X`AP,``*`[0``%````$@`.`%X$``"P.T``XP$``!(`#@"+!```8$]``($#
M```2``X`2@0```C"0```````$``9`,8#``"@/4``)````!(`#@#Y`P```&!`
M``0````1`!``.`0``%320```````$``9`%8$``"`.D``+@```!(`#@!K!```
MT$-``/4````2``X`?00``$!#0`!J````$@`.`.P#``#XP4```````!``&`#3
M`P``T#U``-L````2``X`OP,```C"0```````$``8`"X$```$PD``!````!$`
M&`!W`P``P%-```4````2``X`'@0``%!30`!E````$@`.`/(#````)D``,```
M`!(`#@#N`P``^,%````````@`!@`F`,``+!#0``?````$@`.``@$``#P.D``
MJ@```!(`#@`]!```L#Y``(X$```2``X``%])5$U?9&5R96=I<W1E<E1-0VQO
M;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A
M8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?
M;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?
M<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H
M<E]K97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M
M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G
M=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!0
M97)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?
M<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`'!T:')E861?9V5T<W!E8VEF:6,`
M8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&5X
M:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M
M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L
M96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`&QS=&%T-C0`
M7U]S=')N8W!Y7V-H:P!O<&5N9&ER`'-T9&5R<@!G971U:60`<F5A9&QI;FL`
M7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M
M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I
M<F]N`%]?<F5G:7-T97)?871F;W)K`&QI8G!E<FPN<V\N-2XS,BXP`&QI8F1L
M+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&EB
M8W)Y<'0N<V\N,0!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`
M<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?
M<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?
M;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!P87)?:6YI=%]E;G8`7U]B
M<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?
M,BXQ-@!'3$E"0U\R+C,S`"]U<W(O;&EB>#,R+W!E<FPU+S4N,S(N,2]X.#9?
M-C0M<&QD+6QI;G5X+6=N=7@S,BUT:')E860M;75L=&DO0T]210````(``@`"
M``(````"``(``@`"```````"``,```````,````$``(``@````0```````(`
M````````!`````(``@````(``@`"``(````"``(````````````"`````@`"
M``(``````````@````(```````(``@`"``(``@`"``````````0`!``$``(`
M`@`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$````!``$`3P,``!`````@````EI&6!@``!`"A!`````````$`
M`@!?`P``$`````````"SD98&```#`*P$```0````EI&6!@```@"A!```````
M`*B_0``&!0```````+"_0``&!P```````+B_0``&"P```````,"_0``&$0``
M`````,B_0``&%P```````-"_0``&(0```````-B_0``&+````````."_0``&
M+P```````.B_0``&.0```````/"_0``&/@```````/B_0``&0@```````!C`
M0``'`0```````"#`0``'`@```````"C`0``'`P```````##`0``'!```````
M`#C`0``'!@```````$#`0``'"````````$C`0``'"0```````%#`0``'"@``
M`````%C`0``'#````````&#`0``'#0```````&C`0``'#@```````'#`0``'
M#P```````'C`0``'$````````(#`0``'$@```````(C`0``'$P```````)#`
M0``'%0```````)C`0``'%@```````*#`0``'&````````*C`0``'&0``````
M`+#`0``'&@```````+C`0``'&P```````,#`0``''````````,C`0``''0``
M`````-#`0``''@```````-C`0``''P```````.#`0``'(````````.C`0``'
M(@```````/#`0``'(P```````/C`0``')`````````#!0``')0````````C!
M0``')@```````!#!0``')P```````!C!0``'*````````"#!0``'*0``````
M`"C!0``'*@```````##!0``'*P```````#C!0``'+0```````$#!0``'+@``
M`````$C!0``',````````%#!0``',0```````%C!0``',@```````&#!0``'
M,P```````&C!0``'-````````'#!0``'-0```````'C!0``'-@```````(#!
M0``'-P```````(C!0``'.````````)#!0``'.@```````)C!0``'.P``````
M`*#!0``'/````````*C!0``'/0```````+#!0``'/P```````+C!0``'0```
M`````,#!0``'00```````,C!0``'0P```````-#!0``'1````````-C!0``'
M10```````.#!0``'1@```````.C!0``'1P```````/#!0``'2```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!<&?``!(A<!T`O_02(/$",,``````/\UXI\``/\EY)\`
M``\?0`#_)>*?``!H`````.G@_____R7:GP``:`$```#IT/____\ETI\``&@"
M````Z<#_____)<J?``!H`P```.FP_____R7"GP``:`0```#IH/____\ENI\`
M`&@%````Z9#_____);*?``!H!@```.F`_____R6JGP``:`<```#I</____\E
MHI\``&@(````Z6#_____)9J?``!H"0```.E0_____R62GP``:`H```#I0/__
M__\EBI\``&@+````Z3#_____)8*?``!H#````.D@_____R5ZGP``:`T```#I
M$/____\E<I\``&@.````Z0#_____)6J?``!H#P```.GP_O___R5BGP``:!``
M``#IX/[___\E6I\``&@1````Z=#^____)5*?``!H$@```.G`_O___R5*GP``
M:!,```#IL/[___\E0I\``&@4````Z:#^____)3J?``!H%0```.F0_O___R4R
MGP``:!8```#I@/[___\E*I\``&@7````Z7#^____)2*?``!H&````.E@_O__
M_R4:GP``:!D```#I4/[___\E$I\``&@:````Z4#^____)0J?``!H&P```.DP
M_O___R4"GP``:!P```#I(/[___\E^IX``&@=````Z1#^____)?*>``!H'@``
M`.D`_O___R7JG@``:!\```#I\/W___\EXIX``&@@````Z>#]____)=J>``!H
M(0```.G0_?___R72G@``:"(```#IP/W___\ERIX``&@C````Z;#]____)<*>
M``!H)````.F@_?___R6ZG@``:"4```#ID/W___\ELIX``&@F````Z8#]____
M):J>``!H)P```.EP_?___R6BG@``:"@```#I8/W___\EFIX``&@I````Z5#]
M____)9*>``!H*@```.E`_?___R6*G@``:"L```#I,/W___\E@IX``&@L````
MZ2#]____)7J>``!H+0```.D0_?___R5RG@``:"X```#I`/W___\E:IX``&@O
M````Z?#\____)6*>``!H,````.G@_/___R5:G@``:#$```#IT/S___\E4IX`
M`&@R````Z<#\____)4J>``!H,P```.FP_/___R5"G@``:#0```#IH/S___\E
M.IX``&@U````Z9#\____)3*>``!H-@```.F`_/___R4JG@``:#<```#I</S_
M__\E(IX``&@X````Z6#\____)1J>``!H.0```.E0_/___R42G@``:#H```#I
M0/S___\E"IX``&@[````Z3#\__]!5%6#["B)?"0,C7PD#(ET)`B-="0(B50D
M!(U4)`1DBP0E&````(E$)!PQP.CO_?__BS6QFP``BSV[FP``2(GRZ)LO``"+
M!8V;``!G@#@`#X0I`0``BRUUFP``9XM]`.A,____9XM]`&>`B`8#```"Z#O_
M__]G@(@&`P```8M$)`R->`6!_____S\/AV@!``#!YP+H^/S__XM\)`B+3"0,
MQP6NK0``!````$F)P8D%H:T``(G&9XL'9T&)`8T%%CT``&=!B4$$Q\`$PD``
M9XL`9T&)00B-!0`]``!G08E!#+@!````@_D!?A9F#Q]$``!GBQ2'9XE4A@R#
MP`$YP77P9\=$C@P`````BSU1K0``C5$#13'`3(G)C36B%0``Z*W]__]!B<2%
MP`^$@P```(L]+*T``(UL)!CH\_O__S'`2(GNC3UK.P``Z$,/``!(A<!T<HL]
M"*T``.B3^___Z"[]__^+1"0<9"L$)1@````/A9,```"#Q"A$B>!=05S#Z/W[
M__^)!=>L``!(B<>%P'1MZ$O[__^++36:``!GBWT`Z`S^__]GQH"U!@```.FJ
M_O__BSVIK```Z-3]__]!B<3I:O___XL]DJP``(7_=`KH+2T``.EZ____C3V*
M.@``2(GNZ*H.``")!7"L``")QX7`#X1<____Z];H`_W__[\!````Z#G\___H
MU/W__P\?0`#S#Q[Z,>U!B=&+-"2#Q`2)XH/D\%!40<?`P%-``,?!4%-``,?'
M\"-``/\5P9D``/3S#Q[ZPV8N#Q^$``````"0C3W"FP``C06\FP``.?AT$(L%
M4ID``(7`=`:)P/_@9I##9F8N#Q^$```````/'T``C3V2FP``C36,FP``*?Z)
M\,'N'\'X`@'&T?YT%(L%9ID``(7`=`J)P/_@9@\?1```PV9F+@\?A```````
M#Q]``(`]:9L```!U%U6)Y>A_____Q@58FP```5W#9@\?1```PV9F+@\?A```
M````#Q]``.N.9BX/'X0```````\?0`!!54%455.![%@!``!DBP0E&````(F$
M)$P!```QP(GBD&>+3(<<#\EGB0R"@\`!@_@0=>V-C"0``0``9@\?1```9XM"
M-&<S0B"#P@1G,T($9S-"_-'`9XE"/#G*=>-GBR]GBU\0BP0D9T2+5PB)ZF=$
MBT\,9T2+7P1!B>S!P@5%B="+3"0$0<',`HV$`YEY@EI$BVPD#`'"1(G008V,
M"9EY@EI$,<A$(=A$,<@!T$2)VL'*`D$QT(G602'H1#'F13'0(<9!`<B)P3'6
MP<@"P<$%0HV4*IEY@EI$BVPD$$$!R(M,)`A!C8P*F7F"6@'.1(G!P<$%`<Y$
MB>$QP40AP4'!R`)$,>%'C:0LF7F"6D2+;"04`=&)\L'"!0'1B<)$,<(A\C'"
M0HV$*)EY@EI$BVPD&$0!XD&)S$'!Q`7!S@)$`>)%B<1!,?1!(<S!R0)%,<1'
MC80HF7F"6D2+;"0<1`'@08G40<'$!40!X$&)]$$QS$$AU,'*`D$Q]$*-M"Z9
M>8):1(ML)"!%`>!!B<1!P<0%10'@08G,03'402'$P<@"03',0HV,*9EY@EI$
MBVPD)$0!YD6)Q$'!Q`5$`>9!B=1!,<1%(<1!P<@"03'40HV4*IEY@EI$BVPD
M*$0!X4&)]$'!Q`5$`>%!B<1%,<1!(?3!S@)!,<1"C80HF7F"6D2+;"0L1`'B
M08G,0<'$!40!XD6)Q$$Q]$$AS,')`D4QQ$>-A"B9>8):1(ML)#!$`>!!B=1!
MP<0%1`'@08GT03',02'4P<H"03'T0HVT+IEY@EI$BVPD-$4!X$&)Q$'!Q`5%
M`>!!B<Q!,=1!(<3!R`)!,<Q"C8PIF7F"6D2+;"0X1`'F18G$0<'$!40!YD&)
MU$$QQ$4AQ$$QU$*-E"J9>8):1(ML)#Q$`>%!B?1!P<0%1`'A0<'(`D&)Q$4Q
MQ$$A],'.`D$QQ$*-A"B9>8):1(ML)$!$`>)!B<Q!P<0%1`'B18G$03'T02',
MP<D"13'$1XV$*)EY@EI$BVPD1$0!X$&)U$'!Q`5$`>!!B?1!,<Q!(=3!R@)!
M,?1"C;0NF7F"6D2+;"1(10'$08G`0<'`!44!Q$&)R$$QT$$AP,'(`D$QR$*-
MC"F9>8):1(ML)$Q!`?!$B>;!Q@5!`?")UC'&1"'F,=9!P<P"0HV4*IEY@EH!
MSD2)P<'!!0'.B<%$,>%$(<$QP0'*B?'!P04!RD2)P42+1"10P<D"0HV$`*'K
MV6Y%B>!!,<A!,?#!S@)!`<")T$&)]8G.P<`%1#'N00'`BT0D5#'608V$!*'K
MV6X!QD2)P,'`!0'&B="+5"18P<@"C901H>O9;D2)Z3'!1#'!0<'(`@'1B?+!
MP@4!T8M4)%Q%C:05H>O9;HG"1#'",?)$`>)!B<S!S@)!P<0%1`'B1(MD)&!&
MC:0@H>O9;D2)P#'P,<C!R0)$`>!!B=1!P<0%1`'@1(MD)&1'C:0@H>O9;D&)
M\$$QR$$QT,'*`D4!X$&)Q$'!Q`5%`>!$BV0D:$:-I":AZ]ENB<XQUC'&P<@"
M1`'F18G$0<'$!40!YD2+9"1L1HVD(:'KV6Z)T3'!1#'!0<'(`D0!X4&)]$'!
MQ`5$`>%$BV0D<$:-I"*AZ]ENB<)$,<(Q\D0!XD&)S$'!Q`5$`>)$BV0D=,'.
M`D:-I""AZ]EN1(G`,?`QR,')`D0!X$&)U$'!Q`5$`>!$BV0D>$>-I""AZ]EN
M08GP03'(03'0P<H"10'@08G$0<'$!44!X$2+9"1\1HVD)J'KV6Z)SC'6,<;!
MR`)$`>9%B<1!P<0%1`'F1(ND)(````!&C:0AH>O9;HG1,<%$,<%!P<@"1`'A
M08GT0<'$!40!X42+I"2$````1HVD(J'KV6Z)PD0QPC'RP<X"1`'B08G,0<'$
M!40!XD2+I"2(````1HVD(*'KV6Y$B<`Q\#'(P<D"1`'@08G40<'$!40!X$2+
MI"2,````1XV$(*'KV6Y!B?1!,<Q!,=3!R@)%`<1!B<!!P<`%10'$1(N$))``
M``!"C;0&H>O9;D&)R$$QT$$QP,'(`D$!\$2)YL'&!4$!\(NT))0```"-C#&A
MZ]ENB=8QQD0QYD'!S`(!SD2)P<'!!0'.BXPDF````(V4"J'KV6Z)P40QX40Q
MP4'!R`(!T8GR18G%P<(%`=&+E"2<````C800H>O9;D2)XD0QPC'R`<*)R,'.
M`L'`!4$A]0'"1(G`"?`AR,')`D0)Z$2+K"2@````1XVD+-R\&X]!B?5$`>!!
MB=1!(<U!P<0%1`'@08GT00G,02'4P<H"10GL1(NL)*0```!'C80HW+P;CT&)
MS44!X$&)Q$$AU4'!Q`5%`>!!B<Q!"=1!(<3!R`)%">Q$BZPDJ````$*-M"[<
MO!N/08G51`'F18G$02'%0<'$!40!YD&)U$$)Q$4AQ$4)[$2+K"2L````0HV,
M*=R\&X]!B<5$`>%!B?1!P<@"0<'$!44AQ40!X4&)Q$4)Q$$A],'.`D4)[$2+
MK"2P````0HV4*MR\&X]%B<5$`>)!B<Q!(?5!P<0%1`'B18G$00GT02',P<D"
M10GL1(NL)+0```!"C80HW+P;CT&)]40!X$&)U$$AS4'!Q`5$`>!!B?1!"<Q!
M(=3!R@)%">Q$BZPDN````$>-A"C<O!N/08G-10'@08G$02'50<'$!44!X$&)
MS$$)U$$AQ$4)[$2+K"2\````0HVT+MR\&X]!B=5$`>9%B<3!R`)!P<0%02'%
M1`'F08G400G$12'$0<'(`D4)[$2+K"3`````0HV,*=R\&X]!B<5$`>%!B?1%
M(<5!P<0%1`'A08G$10G$02'TP<X"10GL1(NL),0```!"C90JW+P;CT6)Q40!
MXD&)S$$A]4'!Q`5$`>)%B<1!"?1!(<S!R0)%">Q$BZPDR````$*-A"C<O!N/
M08GU1`'@08G402'-0<'$!40!X$&)]$$)S$$AU$4)[$2+K"3,````1XV$*-R\
M&X]!B<U%`>!!B<3!R@)!P<0%02'510'@08G,00G402'$P<@"10GL1(NL)-``
M``!"C;0NW+P;CT&)U40!YD6)Q$$AQ4'!Q`5$`>9!B=1!"<1%(<1!P<@"10GL
M1(NL)-0```!"C8PIW+P;CT&)Q40!X4&)]$4AQ4'!Q`5$`>%!B<1%"<1!(?3!
MS@)%">Q$BZPDV````$*-E"K<O!N/18G%1`'B08G,02'U0<'$!40!XD6)Q$$)
M]$$AS$4)[$2+K"3<````0HV$*-R\&X]!B?5$`>!!B=3!R0)!P<0%02'-1`'@
M08GT00G,02'4P<H"10GL1(NL).````!'C80HW+P;CT&)S44!X$&)Q$$AU4'!
MQ`5%`>!!B<Q!"=1!(<3!R`)%">Q$BZPDY````$*-M"[<O!N/08G51`'F18G$
M02'%0<'$!40!YD&)U$$)Q$4AQ$'!R`)%">Q$BZPDZ````$*-C"G<O!N/08G%
M00',B?%%(<7!P05!`<R)P40)P2'Q1`GI1(NL).P```!"C90JW+P;CP'*1(GA
MP<X"P<$%08GU`<J+C"3P````C80(UL%BRD2)P3'Q1#'A0<',`@'!B=!$,>;!
MP`4QU@'!BX0D]````$&-A`#6P6+*`<:)R,'`!0'&B="+E"3X````P<@"08V4
M%=;!8LI%B>5!,<5!,<W!R0)!`=6)\D&)R(G!P<(%1#'!00'5BY0D_````#'Q
MP<X"08V4%-;!8LI$BZ0D!`$```'11(GJP<(%1XVD(-;!8LH!T8N4)``!``"-
MA!#6P6+*1(G"08GP,?)$,>H!PHG(P<`%`<)$B>C!R`)!,<!!,<C!R0)%`>!!
MB=1!P<0%10'@1(ND)`@!``!&C:0FUL%BRHG&,<XQUL'*`D0!YD6)Q$'!Q`5$
M`>9$BZ0D#`$``$:-I"#6P6+*B<@QT$0QP$'!R`)$`>!!B?1!P<0%1`'@1(ND
M)!`!``!&C:0AUL%BRHG11#'!,?'!S@)$`>%!B<1!P<0%1`'A1(ND)!0!``!&
MC:0BUL%BRD2)PC'R,<+!R`)$`>)!B<Q!P<0%1`'B1(ND)!@!``!'C80@UL%B
MRD&)]$$QQ$$QS,')`D4!Q$&)T$'!P`5%`<1$BX0D'`$``$*-M`;6P6+*08G`
M03'(03'0P<H"00'P1(GFP<8%00'PB[0D(`$``(VT,-;!8LJ)R#'01#'@0<',
M`@'P1(G&P<8%`?"+M"0D`0``C8PQUL%BRHG61#'F1#'&0<'(`@'.B<'!P04!
MSHN,)"@!``"-E`K6P6+*1(GA1#'!,<'!R`(!T8GR08G%P<(%`=&+E"0L`0``
M08V4%-;!8LI%B<1!,<1!,?1!`=2)RL'.`L'"!4$Q]4$!U(N4)#`!``!!,<W!
MR0)!C900UL%BRD6)X$$!U42)XD'!R`+!P@5!`=6+E"0T`0``C900UL%BRHGP
M,<A$,>!!B<P!T$2)ZD4QQ,'"!44Q[`'0BY0D.`$``(V4%M;!8LI$B>Y!`=2)
MPL'.`L'"!4$!U(N4)#P!``!%`>.-E!76P6+*9T2)7P0!T42)PC'R1`'.,<+!
MR`)GB7<,`<I$B>%!`<+!P05G1(E7"`'*00'89XD79T2)1Q"+A"1,`0``9"L$
M)1@```!U#8'$6`$``%M=05Q!7</H5>___P\?1```05=!5D%505154X/L"$B%
M_P^$N@```(L%%(L``&=$BRA%A>T/A*<```!G#[8'28G_28GTA,!T!#P]=4U%
M,?9G08M=`(7;="U$B>UF#Q]$``")WT2)\DR)_NB#[O__A<!U"&="@#PS/70_
M9XM=!(/%!(7;==R#Q`B)V%M=05Q!74%>05_##Q]``$&)_F=!#[9&`4&#Q@&$
MP'0$/#UU[D4I_NN<9@\?1```1"GM0HU<,P'!_0*)V&=!B2PD@\0(6UU!7$%=
M05Y!7\,/'X0``````(/$"#';B=A;74%<05U!7D%?PV9F+@\?A```````#Q\`
M059!54%455.![*````!DBP0E&````(F$))P````QP$B%_W0)9X`_`$B)_74K
MBX0DG````&0K!"48````#X4=`0``@<2@````6UU!7$%=05[##Q^``````.C3
M[/__1(TM,"H``$&)Q(7`=,),B>?HK>K__X7`#X2E````9X!X$RZ-6!-U"V>`
M>P$`=-\/'T``9X!X$RX/A)T```!(B>_HO>O__TB)WT&)QNBRZ___08U\!@+H
M^.S__T2)Z4F)V4F)Z$F)QDB)Q[K_____O@$````QP.C8Z___3(GWB>;HGNK_
M_TR)]X/X_W00BT0D&"4`\```/0!```!T7NA!Z___3(GWZ`GJ__],B>?H$>K_
M_X7`#X5D____9@\?A```````3(GGZ"CM__](B>_HT.G__^GX_O__#Q\`9X![
M`2X/A5C___]G@'L"``^$'?___^E(____#Q]$``#HH_[__^N@Z/SL__]F9BX/
M'X0``````)!52(G]@>R@````9(L$)1@```")A"2<````,<")YNB^Z?__A<!U
M.HM4)!B!X@#P``"!^@!```!T"('Z`*```'4BO@(```!(B>_H`^G__X7`#Y3`
M#[;`ZPMF#Q^$```````QP(N,))P```!D*PPE&````'4(@<2@````7</H<.S_
M_T%6NO\/``!!54F)]4%454B)_8T]DB@``('L&!```&2+!"48````B80D#!``
M`#'`B>9)B?3H]^K__X7`?DMG@'P$_P!$C7#_=7]%A?9T.D2)\KXO````3(GG
MZ%+I__](A<!T)8L%]X<``&>+..C/Z___1(GQ3(GB2(GN2(G'Z([K___K(`\?
M0`"+!=*'``!GBSCHJNO__TR)ZDB)[DB)Q^@\Z?__BX0D#!```&0K!"48````
M=1B!Q!@0``!=05Q!74%>PP\?1```08G&ZX'HGNO__V9F+@\?A```````#Q\`
M05=!5D%505152(G]4TB)\X/L*&2+!"48````B40D'#'`9X`^/74#@\,!2(G?
MZ%[I__](B>^-="08B40D"$&)QC'`Z/G[__](B<=!B<6%P`^$`P$``.@VZ?__
M03G&#X;5````BT0D&$2+)0*'``!$C32%`````&</MD4`A,`/A)4!```\/0^$
MC0$``(GH#Q\`9P^V4`&#P`&$TG0%@/H]=>\IZ(MT)`AG10,T)(U\,`+H*^K_
M_V=!B0:%P'149T&+!"2+5"08C4T!9XL4D&</MD4`9X@"A,!T'3P]=0?K%Y"$
MP'02@\$!@\(!9P^V0?]GB`(\/77J9\8"/3'`#Q]``&</M@P89XA,`@&#P`&$
MR77OBT0D'&0K!"48````#X4)`0``@\0H6UU!7$%=05Y!7\,/'X``````,<!F
M#Q]$``!G#[84&&=!B%0%`(/``832=>[KO0\?0`!$BR41A@``9T6+/"1G08L/
MA<D/A*\```!%,>T/'T0``$2)Z$&#Q0%G0XL4KX72=?"--(4,````BP5KF```
MA<!U5\<%79@```$```")]^@VZ?__B40D#$B)QX7`#X18____1HTTK0````!$
MB?Y$B?+HY.?__T2+1"0,9T&)!"1G0\=$J`0`````1(EL)!CIC/[__V8/'T0`
M`$2)_^@8Z?__9T&)!"1!B<"%P`^$"?___T:--*T`````Z\1F#Q]$```QP.F$
M_O__O@@```!%,>WI8____^A?Z?__9F8N#Q^$```````/'T``@^P(BP4WA0``
M9XLXZ`_I__^+%2&%``"#Q`B-#7!D``!(B<>--7`E``#ILN?__V:04XL="84`
M`&>+.^CAZ/__2(G'Z+G___]GBSOHT>C__XT-T"8``$4QR5O'PF!/0`!(B<=)
MB<B--4HE``#IX.?__T%455.!["`@``!DBP0E&````(F$)!P@```QP(GE1(VD
M)!`0``#H)NC__TB)[XT-)R4``$2-#>LD``!!B<"Z`1```+X!````,<#HXN;_
M_TB)[[H`$```3(GFZ$+G__\Q[87`>".->`&)P^C"Y___2(G'B<6%P'00B=I,
MB>;H;^;__V?&1!T``(GHBXPD'"```&0K#"48````=0N!Q"`@``!;74%<P^@V
MZ/__9@\?1```Z4O___]F9BX/'X0``````$%7059)B?9!54%454B)_8T]DR0`
M`%.![+@0``!DBP0E&````(F$)*P0```QP(UT)`SHFOC__[XO````2(GOB</H
MN^3__TB%P'0^2(GNC3U>)```,<#H-OS__XGHBY0DK!```&0K%"48````#X5M
M`0``@<2X$```6UU!7$%=05Y!7\-F#Q]$``!(B>]$C24L)```Z(GE__],B>9,
MB?=!B<7HJ^7__T&)QX7`=)Y!@\4!9T&`/P`/A,<````/'T0``$6)_H7;=!*)
MWTR)]NB_X___A<`/A(D```!,B??H/^7__V=!@'P'_R]U&&8/'T0``(/H`6=!
M@'P'_R]G0<8$!P!T[D0!Z#W_#P``#X\Z____C0V0)```N@`0``!%B?@QP$2-
MM"2@````@^P(O@$```!51(T-B",``$R)]^@PY?__C70D($R)]^CTX___6EF%
MP'40BT0D*"4`\```/0"```!T3DR)YC'_Z.3D__]!B<>%P`^$T_[__V=!@#\`
M#X4^____A=MT!F>`.RYT%$2-/1,C``"X`0```.EE____#Q\`9X![`0!TN^OC
M#Q^``````+X!````3(GWZ,/B__^%P'6A3(GVC3WG(@``Z,'Z__],B??H6>;_
M_XG%Z7S^___H/>;__V9F+@\?A```````9I!G#[87A-)T&8GX9@\?1```@\`!
M@/HO9P^V$`]$^(32=>^)^,-F9BX/'X0``````)!(A?\/A,<```!52(G]4X/L
M"&>`/P`/A(4```#HX./__XU4*/\YZG<3Z8,````/'P"#Z@$YZ@^$?0```&>`
M.B]T[SGJ=FL/'P"#Z@$YZG1I9X`Z+W7S.>IU#>M%#Q]$``!G@#HO=0>#Z@$Y
MZG?S*>HQP(U*`H'Y`!```'<;C3WN@P``@\(!N0`0``!(B>Y(B?OHR^3__XG8
M@\0(6UW##Q\`@\0(C3W=(0``6UWI8.7__SGJ=;(/'T``9X`Z+W3B@\0(C3W9
M(0``6UWI0N7__V:0C3VP(0``Z37E__\/'T0``$%7059!54%458TMLR$``%.#
M[%AF#V\%56```&2+!"48````B40D3#'`C5PD'#'`#Q%$)"!F#V\%1&```&:)
M1"1`B5PD#`\11"0P9@\?1```,<!(B=Y(B>_H<_7__TB%P'0NBP68@```BU0D
M'&>+`(T$D&>+4`1GB1"%TG33#Q\`9XM0"(/`!&>)$(72=?+KP(M<)`R-+3$A
M``!F#Q]$```QP$B)WDB)[^@C]?__2(7`="Z+!4B```"+5"0<9XL`C0209XM0
M!&>)$(72=-,/'P!GBU`(@\`$9XD0A=)U\NO`BUPD#(TMZ2```&8/'T0``#'`
M2(G>2(GOZ-/T__](A<!T+HL%^'\``(M4)!QGBP"-!)!GBU`$9XD0A=)TTP\?
M`&>+4`B#P`1GB1"%TG7RZ\"+7"0,C2VB(```9@\?1```,<!(B=Y(B>_H@_3_
M_TB%P'0NBP6H?P``BU0D'&>+`(T$D&>+4`1GB1"%TG33#Q\`9XM0"(/`!&>)
M$(72=?+KP(M<)`R-+5D@``!F#Q]$```QP$B)WDB)[^@S]/__2(7`="Z+!5A_
M``"+5"0<9XL`C0209XM0!&>)$(72=-,/'P!GBU`(@\`$9XD0A=)U\NO`BUPD
M#$2-)1@@```/'T0``#'`2(G>3(GGZ./S__](A<!T+HL%"'\``(M4)!QGBP"-
M!)!GBU`$9XD0A=)TTP\?`&>+4`B#P`1GB1"%TG7RZ\"+7"0,1(TE?1\```\?
M1```,<!(B=Y,B>?HD_/__TB%P'0NBP6X?@``BU0D'&>+`(T$D&>+4`1GB1"%
MTG33#Q\`9XM0"(/`!&>)$(72=?+KP(M<)`Q$C36$'P``#Q]$```QP$B)WDR)
M]^A#\___2(7`="Z+!6A^``"+5"0<9XL`C0209XM0!&>)$(72=-,/'P!GBU`(
M@\`$9XD0A=)U\NO`BUPD#$2-+3X?```/'T0``#'`2(G>3(GOZ//R__](A<!T
M+HL%&'X``(M4)!QGBP"-!)!GBU`$9XD0A=)TTP\?`&>+4`B#P`1GB1"%TG7R
MZ\"+7"0,1(T]^!X```\?1```,<!(B=Y,B?_HH_+__TB%P'0NBP7(?0``BU0D
M'&>+`(T$D&>+4`1GB1"%TG33#Q\`9XM0"(/`!&>)$(72=?+KP$2+?"0,C1U&
M'@``#Q]$```QP$R)_DB)W^A3\O__2(7`="Z+!7A]``"+5"0<9XL`C0209XM0
M!&>)$(72=-,/'P!GBU`(@\`$9XD0A=)U\NO`3(G^C3UD'@``Z!+R__](B<:%
MP'0*3(GO,<#HP?7__XMT)`R-/54>```QP.CP\?__2(G&A<!T#8T]4QX``#'`
MZ)SU__]$BVPD#(T]3!X``#'`3(GNZ,?Q__](B<:%P'0V3(GG,<#H=O7__S'`
MC355'@``2(GOZ&;U__^+1"1,9"L$)1@```!U48/$6%M=05Q!74%>05_#3(GN
MC3T,'@``,<#H>O'__TB)QH7`=`Q,B?<QP.@I]?__Z[%(N%!!4E]#3$5!2#E$
M)#%UH&:!?"0Y3CUUEXUT)#OKU.B2X/__9I"#[!ADBP0E&````(E$)`R+!:M^
M``"#^/]T%HM\)`QD*SPE&````'4]@\08PP\?0`"-="0(C3TU'0``,<#H__#_
M_TB)PC'`A=)T$V</MA*`^C`/E<$QP(32#Y7`(<B)!5U^``#KM>@FX/__9@\?
M1```@^P(Z+C>__^)Q^BAW/__2(G"B<"%TG0#9XL`@\0(PY!!54%41(TERAT`
M`%5(B?U,B>=3@^P89(L$)1@```")1"0,,<"-="0(Z(/P__^%P'0&9X`X`'4I
MBT0D#&0K!"48````#X6G````2(GN@\083(GG,<!;74%<05WI$?3__Y!(B>Y(
MB<=(B</H$MW__TB%P'0=BT0D#&0K!"48````=6^#Q!A;74%<05W##Q]$``!(
MB>_H:-W__TB)WT&)Q>A=W?__08U\!0+HH][__X/L"+K_____28GH4TB)QTF)
MQ42-#=@;``"-#;H<``"^`0```#'`Z'C=__]86HM$)`QD*P0E&````'4(3(GN
MZ5S____H"]___V9F+@\?A```````05=!5DF)_D%505154X'L>($``&2+!"48
M````B80D;($``(T%/1P``(UT)$3'1"10`````,=$)'0`````28GUQT0D7```
M``")1"1(C04U&P``B40D3(T%OAL``(E$)&2-!04<``")1"1HC07'&P``B40D
M;(T%^1L``(E$)'"-!=8;``")1"14C07I&P``B40D6(T%\1H``$B)1"0@2(G'
M,<#H"N___X7`=`IG@#@`#X6<!```,<#H)?[__XG%A<`/A.L#``")[^@TW/__
MC7P``>A[W?__9T0/MD4`08G$183`=#I%B>>-'9,;```/'T``1(G_10^VP$B)
MV;K_____O@$````QP(/%`4&#QP+H/MS__V=$#[9%`$6$P'731(U\)&"-!?@:
M``!$B>OK%`\?`&=!BT<$08/'!(7`#X1'`0``B<=(B=XQP.AC[O__2(G%A<!T
MW&>`.`!TUDB)Q^BN\/__A<!TRDB)[^BBW?__08G`A<`/A`\!```/'X``````
M1(G#2(G?Z'7;__]$B>)(B==(B50D$(G%Z&/;__]$C;P%!`0``(TM]1D``$2)
M_^B=W/__28G828GIO@$```!(BU0D$$B)1"0(2(G'08G$C06Y&@``C0VJ&@``
M2(G[4KK_____4#'`Z&7;__^^P`$``$B)W^CXVO__05A!68/X_W43Z+K:__]G
M1(L(08/Y$0^%"@,``$B+?"0(C;0D@````(ET)"SHQ]G__XG#A<`/A*T```"+
M!==X``!G08L.O@$```"-%?@:``!,BT0D"$4Q[6>+.#'`Z";9__^+A"1L@0``
M9"L$)1@````/A18(``"!Q'B!``!,B>A;74%<05U!7D%?PP\?1```BT0D2(U<
M)$CK$68/'T0``&>+0P2%P'0X@\,$9X`X`'0OB<5(B>_H7>___X7`=.%(B>_H
M4=S__T&)P(7`#X6V_O__9XM#!(7`=<YF#Q]$``!%,<#IH/[__XN$))@````E
M`/```#T`0```#X4\____BX0DG````(E$)!#HF=K__SE$)!`/A2+___^+A"28
M````)?\!```]P`$```^%"____T2)_^@@V___C3U<&0``1(GN2(E$)!B)1"0P
M,<#H9^S__TB)QX7`#X0\`@``Z+?;__]G08L^2(G&Z'OS__]!B<6%P`^$(`(`
M`$2)[^B(V?__@_@#=C-!C70%_+D%````C3T*&0``9_.F#Y?"@-H`A-)U%H/X
M!`^$DP4``&=!@'P%^R\/A(8%```QP.BY^O__A<!U%42)[S'VZ)O8__]!B<>%
MP`^%R0$``(TU@1@``(T]`Q@``#'`Z(WO__]$C37K&```1(T]S1@``.AZVO__
M05:Z_____TF)Z5!,BT0D&(T-I!@``#'`2(M\)"B^`0```.@SV?__6%I$BVPD
M,.M$9BX/'X0``````.B+V/__9X,X$75!Z##:__^#PP&#[`A$B?E!5DF)Z46)
MX+K_____4[X!````3(GO4#'`Z.G8__^#Q""^P`$``$R)[^AYV/__@_C_=+1(
MBWPD".@JU___2(M<)!A(BWPD(#'`2(G>Z-;N__](B=_H7OK__^FS_?__9@\?
MA```````1(UD)%2-!9X7``!$B>OK#F=!BT0D!(7`=#9!@\0$B<=(B=XQP.C6
MZO__2(G'A<!TWV>`.`!TV>@DVO__B<6%P`^%S_O__V=!BT0D!(7`=<J_#0``
M`(TM4Q<``.A`V?__0;A3````08G$Z<7[__^+!>QU``!G08L.O@$```"-%<T7
M``!,BT0D"$4Q[6>+.#'`Z#O6___I$/W__V8/'T0``$B)QTB)Q>BE^?__BX0D
M;($``&0K!"48````#X45!0``@<1X@0``2(GO6UU!7$%=05Y!7^F(V?__#Q^$
M``````!G18LNZ=?]__^Z`@```$C'QN[___^)Q^@4V?__C9PD8`$``+H&````
M1(G_2(G>B5PD$.AIUO__@+PD8`$```!U#H"\)&$!``!##X0?!```,=(Q]D2)
M_^C5V/__2(EL)#A(N`$C16>)J\WO2(F$)(````!(N/[<NIAV5#(02(F$)(@`
M``"X\.'2PTB)A"20````C80DG````,>$))@`````````QX0DW`````````")
M1"0T9@\?1```1(ML)!"Z`(```$2)_TR)[NC3U?__B<.%P`^.-0$``#')C03=
M`````(ML)!`#A"24````BY0DF`````^2P8F$))0```")V(/Y`8/:_\'H'0'0
MBY0DW````(F$))@```"%T@^%H0```(/[/P^.P`(``(/K0$2+;"0L08G>0<'N
M!D6-9@%!P>0&00'L9@\?1```9_,/;TT`9_,/;U403(GO@\5`9_,/;UW@9_,/
M;V7P#Q&,))P````/$90DK`````\1G"2\````#Q&D),P```#H!=O__T$Y['6X
M0<'F!D0I\XM\)#1$B>:Y1````(G:Z/;6__^)G"3<````Z0+___]F+@\?A```
M````N$````!,B>XIT#G##T[#B<6+1"0TC3P0B>KHH=7__XN$)-P````!Z(F$
M)-P```"#^$`/A<#^__^+?"0L*>L#;"00Z(G:___I$____T2)_TB+;"0XZ#?7
M__^+A"24````2(N<))0```#!Z`-(#\N#X#]GQH0$G````("-2`&#^3@/CJH!
M``"+="0TND`````!SBG*=`XQP&?&!`8`@\`!.=!R](M\)"SH)-K__V8/[\!(
MQX0DS``````````/$80DG`````\1A"2L````#Q&$)+P```"+?"0L1(VL)#`!
M``!(B9PDU````$2-O"01`0``18GN1(VD)%@!``"-'2X4``#HRMG__XN$)(``
M```/MY0D@````(G!P>@0B(0D$0$``&;!P@C!Z1B+A"2$````9HF4)!(!``!!
MB<@/R(F$)!0!``"+A"2(````#\B)A"08`0``BX0DC`````_(B80D'`$``(N$
M))`````/R(F$)"`!``#K#`\?`&=%#[8'08/'`42)]T4/ML!(B=FZ_____[X!
M````,<!!@\8"Z&#4__]%.?1UT\:$)%@!````C072$P``4$%53(M$)!B^`0``
M`$F)Z3'`2(M\)"B-#8$3``"Z_____^@FU/__65Y$BVPD,.E&^___9T6+=@1%
MA?8/A&SZ__]$B??HM-/__X/X`P^&6_K__T&-=`;\N04```"-/3<3``!G\Z8/
ME\`<`(3`10]$[NDX^O__08GLZ:?]__^+1"0TNC@````Q]BG*`<B#^@AS+/;"
M!`^%TP```(72#X1__O__9\8``/;"`@^$<O[__S'_9V:)?!#^Z67^__^0C4@(
M9TC'``````!G2,=$$/@`````@^'X*<@!T(/@^(/X"`^"//[__X/@^#'29TB)
M-!&#P@@YPG+TZ2;^__^`O"1B`0``00^%T_O__X"\)&,!``!##X7%^___@+PD
M9`$``$@/A;?[__^`O"1E`0``10^%J?O__[H"````2,?&QO___T2)_^AVU/__
MNBD```!(B=Y$B?_HUM'__XT%=1(``%!3Z9_^__]F#Q^$``````!GQP``````
M9\=$$/P`````Z9_]___H=M3__V8/'T0``$%6055!5%53@^P0BRU/<```9(L$
M)1@```")1"0,,<!GBWT`Z!C4__]GBWT`B</H#=3__V</ME-DC70D"(T]\1``
M`$F)]6>(4&4QP.C0Y/__A<!T"F>`.#$/A+("```QP.CK[O__9XM]`.C2T___
MN0L```"Z`0```(TUP1$``$B)Q^BZT?__A<`/A+L```!GBT`,@SU/@@```6=$
MBV`8#XZE````,=OK.0\?A```````9T&+=@R+!2F"``!$C7,!9XM\F`3H%]#_
M_T&)P(L%%H(``$6%P'5G@\,".<-$B?-]76>+?0#H5M/__S')B=I,B>9(B<?H
MM]+__X7`=#MG1(LP9T&+1@@E``0@`#T`!```=)YGBWT`Z"73__]$B?:Y`@``
M`#'22(G'Z-/0__^)QNN$#Q^``````(L%JH$``(U0_SG:#X1G`0``9XM]`.CN
MTO__N0,```"Z`0```(TUXA```$B)Q^C6T/__08G$A<!T-&>+0`QGBWT`9XL8
MZ+_2__^-%;\0``!(B<>)WNA/T/__9T&+1"0,9XL89_9#"D`/A:0!``!GBWT`
MZ)+2__^Y`P```+H!````C36-$```2(G'Z'K0__^)PX7`=#A$B>Z-/2P/```Q
MP.A$X___28G$A<`/A#D!``!GBT,,9XM]`&>+&.A)TO__3(GB2(G'B=[HW,__
M_V>+?0#H,]+__[H!````C34U$```2(G'Z,#0__]GBWT`28G$Z!32__^-%3`0
M``!,B>9(B<?HH\___V>+?0#H^M'__T2)[HT]J0X``&?&0&4`,<#HQ>+__XD%
MBX```(G"A<`/A'T```!!B=2^P`$``$R)Y^CES___C5`!@_H!=@F#^!$/A=H`
M``"+1"0,9"L$)1@````/A<,```"#Q!!;74%<05U!7L-F#Q]$``"#^`$/CI#^
M__^[`0```&:09XM]`(/#`>ATT?__3(GF2(G'Z&G.__\Y'0N```!_X>EE_O__
M#Q]``(L]]G\``.A]\O__B07S?P``B<*%P`^%:/___XT]_P\``.CBS___9I!G
M@'@!``^$2OW__^D^_?__BP6^?P``9XM]`&=$BR!GBT,,9XL8Z`;1__]$B>:)
MW^B\Y/__Z;O^__]GBWT`Z.[0__^)WDB)Q^CTS___Z43^___H"M'__XL5>'\`
M`(G!C3V\#P``,<!GBS),B>+H;\___V9F+@\?A```````#Q]``%5(B?U3@^P(
MZ-/J__](B<?HF^K__TB)PS'`Z#'P__^%P'0E2(7M="!G@'T``'09N00```"-
M/3,.``")WF?SI@^7P!P`A,!T"(/$"%M=PV:0@\0(2(GO6UWI(^+__P\?`/,/
M'OI!5T2-/2MK``!!5DF)UD%528GU051!B?Q5C2T9:P``4T0I_8/L".B!S/__
MP?T"=",QVV8N#Q^$``````!G08L$GX/#`4R)\DR)[D2)Y__0.=UUZ8/$"%M=
M05Q!74%>05_#9F8N#Q^$``````#S#Q[ZPV8N#Q^$``````"0\P\>^HL-(FX`
M`.D!S___`/,/'OI(@^P(2(/$",,`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`55-%4@!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`
M4$%42`!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-#4`+64`+2T````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````'!E<FQX
M<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`$;
M`SO@````&P```."`__\D`0``L(3__TP&``#`AO___````/"&__\0`0``L(?_
M_T@!``!`E?__B`$``#"6__\``@``H)?__T0"```@F/__:`(```"9__^D`@``
M0)O___`"``!PF___"`,``+";__\D`P``8)S__U@#``!PG/__;`,``&">___,
M`P``D)[__^`#``!PG___)`0```"D__]T!```<*3__Y`$``"0I/__J`0``)"E
M__\`!0``(+#__]0%``"PL___&`8``!"T__]X!@``@+3__\`&``"0M/__U`8`
M`!0``````````7I2``%X$`$;#`<(D`$``!`````<````O(7__S``````1`<0
M$````#````#8A?__!0`````````@````1````+1____0`P````X01@X82@\+
M=PB``#\:.RHS)"(\````:````&"&__^+#0```$(.$(T"0@X8C`-!#B"&!$$.
M*(,%1@Z``P-S#0H.*$$.($$.&$(.$$(."$$+````=````*@```"PD___X@``
M``!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=##D`":@H..$,.,$$.
M*$(.($(.&$(.$$(."$4+=0H..$$.,$$.*$(.($(.&$(.$$(."$D+0PXX10XP
M00XH0@X@0@X80@X00@X(0````"`!```HE/__9`$```!"#A".`D(.&(T#0@X@
MC`1!#BB&!4$.,(,&1@[0`7H*#C!!#BA!#B!"#AA"#A!"#@A("P`@````9`$`
M`%25__^``````$$.$(8"20ZP`0)O"@X000X(00LX````B`$``+"5___2````
M`$(.$(X"1PX8C0-%#B",!$$.*(8%3P[`(`*="@XH00X@0@X80@X00@X(1@M(
M````Q`$``%26__\Q`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$#CB#
M!T8.8`,3`0H..$$.,$$.*$(.($(.&$(.$$(."$@+%````!`"``!(F/__+@``
M``!##A!7#@@`&````"@"``!@F/__0`````!!#A"#`F@."````#````!$`@``
MA)C__ZH`````0@X0C`)!#AB&`T$.((,$1@[`0`*6"@X@00X800X00@X(00L0
M````>`(```"9__\%`````````%P```",`@``_)C__^,!````0@X0CP)"#AB.
M`T4.((T$0@XHC`5!#C"&!DH..(,'1@[P(0);"@XX00XP00XH0@X@0@X80@X0
M0@X(1PL"HP[X(48.@")<#O@A00[P(0```!````#L`@``C)K__R0`````````
M0``````#``"HFO__VP````!*#A"&`D0.&(,#0PX@`HD*#AA!#A!!#@A$"T,*
M#AA'PPX00<8."$4+40X81\,.$$'&#@A,````1`,``$2;__^.!````$(.$(\"
M0@X8C@-"#B"-!$(.*(P%00XPA@9'#CB#!T,.D`$#*`0*#CA!#C!!#BA"#B!"
M#AA"#A!"#@A!"P```!@```"4`P``A)___VH`````0PX@:`H."$4+```4````
ML`,``-B?__\?`````$,.$%L."`!4````R`,``."?___U`````$(.$(T"0@X8
MC`-(#B"&!$<.*(,%0PY`>0H.*$8.($$.&$(.$$(."$8+9`H.*$$.($$.&$(.
M$$(."$8+8`Y(20Y08`Y(00Y`T````"`$``"(H/__B@H```!"#A"/`D(.&(X#
M10X@C01"#BB,!4$.,(8&00XX@P=&#K"#`@/+`0ZX@P)&#L"#`E8.N(,"0@ZP
M@P(">0H..$0.,$$.*$(.($(.&$(.$$(."$8+`W`!#KB#`DD.P(,"70ZX@P)!
M#K"#`F<.N(,"10[`@P),#LB#`DD.T(,"2@ZP@P(##`$*#CA$#C!!#BA"#B!"
M#AA"#A!"#@A-"P-T`PZX@P)"#L"#`F4.N(,"00ZP@P(#-0$*#KB#`D$.P(,"
M3@L```!`````]`0``$2J__^!`P```$(.$(X"0@X8C0-"#B",!$$.*(8%00XP
M@P9##D`#E@(*#C!!#BA!#B!"#AA"#A!"#@A'"S`````X!0``D*W__UT`````
M00X0A@)$#AB#`T,.(`)#"@X800X000X(0PM##AA$#A!!#@@H````;`4``%Q^
M__\,`@```$(.$(P"00X8A@-##D`#<0$*#AA$#A!"#@A!"T0```"8!0``D*W_
M_V4`````1@X0CP))#AB.`T4.((T$10XHC`5$#C"&!D<..(,'1@Y`<`XX00XP
M00XH0@X@0@X80@X00@X(`!````#@!0``N*W__P4`````````$````/0%``"T
MK?__#P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````.`F0`"P
M)D```0```"@#```!````.@,```$```!%`P```0```$\#```!````7P,```$`
M``!I`P``#P```+<$```,`````"!```T```#@4T``&0```(B^0``;````!```
M`!H```",OD``'`````0```#U_O]O2`)```4````\"4``!@```!P#0``*````
M^@0```L````0````%0`````````#`````,!```(```#0`@``%`````<````7
M````T`]```<```!,#T``"````(0````)````#````/[__V_\#D``____;P(`
M``#P__]O-@Y`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"0OD`````````````````````````````V($```````$8@
M0```````5B!```````!F($```````'8@0```````AB!```````"6($``````
M`*8@0```````MB!```````#&($```````-8@0```````YB!```````#V($``
M``````8A0```````%B%````````F(4```````#8A0```````1B%```````!6
M(4```````&8A0```````=B%```````"&(4```````)8A0```````IB%`````
M``"V(4```````,8A0```````UB%```````#F(4```````/8A0```````!B)`
M```````6(D```````"8B0```````-B)```````!&(D```````%8B0```````
M9B)```````!V(D```````(8B0```````EB)```````"F(D```````+8B0```
M````QB)```````#6(D```````.8B0```````]B)````````&(T```````!8C
M0```````)B-````````V(T```````$8C0```````5B-```````!F(T``````
M`'8C0```````AB-```````"6(T```````*8C0```````MB-```````#&(T``
M`````-8C0```````YB-``````````````````/_____88D``1T-#.B`H4$Q$
M+4QI;G5X*2`Q,"XS+C`@,C`R,3`T,#@@*')E;&5A<V4I```N<VAS=')T86(`
M+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N9VYU+G!R;W!E<G1Y
M`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R
M86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F=O
M="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````
M````````````````````````````````"P````$````"````M`%``+0!```:
M```````````````!`````````!,````'`````@```-`!0`#0`0``)```````
M````````!``````````F````!P````(```#T`4``]`$``#0`````````````
M``0`````````.0````<````"````*`)``"@"```@```````````````$````
M`````$<```#V__]O`@```$@"0`!(`@``U`````8`````````!`````0```!1
M````"P````(````<`T``'`,``"`&```'`````0````0````0````60````,`
M```"````/`E``#P)``#Z!``````````````!`````````&$```#___]O`@``
M`#8.0``V#@``Q`````8``````````@````(```!N````_O__;P(```#\#D``
M_`X``%`````'`````@````0`````````?0````0````"````3`]``$P/``"$
M````!@`````````$````#````(<````$````0@```-`/0`#0#P``T`(```8`
M```7````!`````P```"1`````0````8`````($```"```!L`````````````
M``0`````````C`````$````&````("!``"`@``#0`P`````````````0````
M$````)<````!````!@```/`C0`#P(P``[R\`````````````$`````````"=
M`````0````8```#@4T``X%,```T```````````````0`````````HP````$`
M```"`````&!```!@``!`/P`````````````0`````````*L````!`````@``
M`$"?0`!`GP``Y```````````````!`````````"Y`````0````(````DH$``
M)*````@&``````````````0`````````PP````X````#````B+Y``(BN```$
M```````````````$````!````,\````/`````P```(R^0`",K@``!```````
M````````!`````0```#;````!@````,```"0OD``D*X``!@!```'````````
M``0````(````Y`````$````#````J+]``*BO``!8```````````````(````
M"````.D````!`````P````#`0```L```^`$`````````````"`````@```#R
M`````0````,```#XP4``^+$``!````````````````0`````````^`````@`
M```#````(,)```BR```T$``````````````@`````````/T````!````,```
M```````(L@``*P```````````````0````$````!`````P``````````````
8,[(```8!``````````````$`````````
